@@ -21,6 +21,7 @@ KNOWN_METADATA_KEYS = (
     'name',
     'display-name',
     'summary',
+    'docs',
     'maintainer',
     'maintainers',
     'min-juju-version',
@@ -303,13 +304,7 @@ class Charm(object):
                 # not all charms have a layer.yaml
                 pass
 
-            for key in charm.keys():
-                if key not in KNOWN_METADATA_KEYS:
-                    lint.err("Unknown root metadata field (%s)" % key)
-
-            for key in REQUIRED_METADATA_KEYS:
-                if key not in charm:
-                    lint.err("Missing required metadata field (%s)" % key)
+            validate_metadata_keys(charm, lint)
 
             charm_basename = os.path.basename(charm_path)
             if charm.get('name') != charm_basename:
@@ -800,8 +795,8 @@ def validate_min_juju_version(charm, linter):
     if 'min-juju-version' not in charm:
         return
 
-    pattern = r'^(\d{1,9})\.(\d{1,9})(\.|-(\w+))(\d{1,9})(\.\d{1,9})?$'
-    match = re.match(pattern, charm['min-juju-version'])
+    pattern = r'(\d{1,9})\.(\d{1,9})(?:\.|-([a-z]+))(\d{1,9})(\.\d{1,9})?'
+    match = re.match(pattern, str(charm['min-juju-version']))
     if not match:
         linter.err('min-juju-version: invalid format, try X.Y.Z')
         return
@@ -812,22 +807,22 @@ def validate_min_juju_version(charm, linter):
 
 
 def validate_series(charm, linter):
-    """Validate supported series list in charm metadata.
+    """Validate series list in charm metadata.
 
-    We don't validate the actual series names because:
-
-    1. `charm push` does that anyway
-    2. our list of valid series would be constantly falling out-of-date
+    The `series` parameter is deprecated because charmcraft ignores it and
+    uses `bases` from `charmcraft.yaml`. This function checks if the series
+    is in metadata.yaml and displays an info message if so. Note that it is not
+    a warning as that causes an error in the charm proof which isn't what is
+    wanted.
 
     :param charm: dict of charm metadata parsed from metadata.yaml
     :param linter: :class:`CharmLinter` object to which info/warning/error
         messages will be written
 
     """
-    if 'series' not in charm:
-        linter.err('missing series: must be a list of series names')
-    elif not isinstance(charm['series'], list):
-        linter.err('series: must be a list of series names')
+    if 'series' in charm:
+        linter.info('DEPRECATED: series parameter is ignored by charmcraft,'
+                    'use bases in charmcraft.yaml')
 
 
 def validate_storage(charm, linter, proof_extensions=None):
@@ -1048,3 +1043,20 @@ def validate_categories_and_tags(charm, linter):
             'Categories are being deprecated in favor of tags. '
             'Please rename the "categories" field to "tags".'
         )
+
+
+def validate_metadata_keys(charm, linter):
+    """Validate keys in metadata.yaml.
+
+    :param charm: dict of charm metadata parsed from metadata.yaml
+    :param linter: :class:`CharmLinter` object to which info/warning/error
+        messages will be written
+
+    """
+    for key in charm.keys():
+        if key not in KNOWN_METADATA_KEYS:
+            linter.info("Unknown root metadata field (%s)" % key)
+
+    for key in REQUIRED_METADATA_KEYS:
+        if key not in charm:
+            linter.err("Missing required metadata field (%s)" % key)
